using AutoScan.Implementations;
using AutoScan.Interfaces;
using AutoScan.Listener;
using CasaBotApp;
using Microsoft.Extensions.DependencyInjection;
using Quartz;

namespace AutoScan;

public static class DependencyInjectionExtensions
{
    public static void AddAutoScan(this IServiceCollection services)
    {
        services.AddSingleton<IDVRConnector, ShinobiConnector>();
        services.AddSingleton<IDVRScanner, DVRScanner>();
        services.AddSingleton<IShinobiLinkFactory, ShinobiLinkFactory>();
        
        services.AddSingleton<FfmpegWrapper>();
        services.AddSingleton<AutoScanApp>();
        services.AddSingleton<ISnapshoter, Snapshoter>();
        services.AddQuartz();
        services.AddTransient<IChainerListenerFactory, ChainerListenerFactory>();

        // services.AddQuartzHostedService(q => q.WaitForJobsToComplete = true);
        
        services.AddSingleton<IScheduler>(sp =>
        {
            var schedulerFactory = sp.GetRequiredService<ISchedulerFactory>();
            var tsk = schedulerFactory.GetScheduler();
            tsk.Wait();
            return tsk.Result;
        });

    }
}