using AutoScan.Options;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using Quartz;

namespace AutoScan.Jobs;

public class CleanJob : IJob
{
    private readonly ILogger<CleanJob> _logger;
    private readonly AutoScanOptions _options;

    public CleanJob(IOptions<AutoScanOptions> options, ILogger<CleanJob> logger)
    {
        _options = options.Value;
        _logger = logger;
    }

    public async Task Execute(IJobExecutionContext context)
    {
        _logger.LogInformation("Cleaning up files...");
        _logger.LogInformation("RemoveOriginalFiles: {RemoveOriginalFiles}", _options.RemoveOriginalFiles);
        _logger.LogInformation("RemoveDetectionFiles: {RemoveDetectionFiles}", _options.RemoveDetectionFiles);
        if (_options.RemoveOriginalFiles)
        {
            CleanOriginalFiles();
        }

        if (_options.RemoveDetectionFiles)
        {
            CleanDetectionFiles();
        }

        await Task.Delay(200);
    }
    
    private void CleanOriginalFiles()
    {
        if (_options.MediaFolder is not null)
            return;
        if (_options.RunDry)
            return;
        
        //remove .mp4 files from the media folder
        _logger.LogInformation("Removing .mp4 files from media folder {MediaFolder}", _options.MediaFolder);
        foreach (var file in Directory.GetFiles(_options.MediaFolder!, "*.mp4"))
        {
            File.Delete(file);
        }
    }
    
    private void CleanDetectionFiles()
    {
        if (_options.Scanner?.DetectionFolder is not null)
            return;
        if (_options.Scanner!.RunDry)
            return;
        
        //remove .avi files from the detection folder
        _logger.LogInformation("Removing .avi files from detection folder {DetectionFolder}", _options.Scanner.DetectionFolder);
        foreach (var file in Directory.GetFiles(_options.Scanner!.DetectionFolder!, "*.avi"))
        {
            File.Delete(file);
        }
        
    }
}