using Quartz;

namespace AutoScan.Listener;

public class ChainerListenerBuilder
{
    private readonly ChainerListener _chainerListener;

    private readonly List<IJobDetail> _chain = [];
    
    private Func<Task>? _finishCallback = () => Task.CompletedTask;

    public ChainerListenerBuilder(ChainerListener chainerListener)
    {
        _chainerListener = chainerListener;
    }
    
    public ChainerListenerBuilder AddJob(IJobDetail job)
    {
        _chain.Add(job);
        return this;
    }
    
    public ChainerListenerBuilder OnFinish(Func<Task>? callback)
    {
        _finishCallback = callback;
        return this;
    }
    
    public ChainerListener Build()
    {
        if(_chain.Count < 2)
        {
            throw new Exception("ChainerListenerBuilder requires at least 2 jobs to chain.");
        }
        for (var i = 0; i < _chain.Count -1; i++)
        {
            _chainerListener.AddJobChainLink(_chain[i].Key, _chain[i + 1].Key);
        }
        _chainerListener.OnJobChainFinished = _finishCallback;
        return _chainerListener;
    }
}