using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;

namespace AutoScan.Listener;

public interface IChainerListenerFactory
{
    ChainerListener CreateChainerListener(string name);
    ChainerListenerBuilder Start(string name);
}

public class ChainerListenerFactory : IChainerListenerFactory
{
    private readonly ILoggerFactory _loggerFactory;

    public ChainerListenerFactory(ILoggerFactory loggerFactory)
    {
        _loggerFactory = loggerFactory;
    }
    
    public ChainerListener CreateChainerListener(string name)
    {
        var logger = _loggerFactory.CreateLogger<ChainerListener>();
        return new ChainerListener(name, logger);
    }

    public ChainerListenerBuilder Start(string name)
    {
        var logger = _loggerFactory.CreateLogger<ChainerListener>();
        return new ChainerListenerBuilder(new ChainerListener(name, logger));
    }
}

